@@ -26,13 +26,18 @@ from oslo_reports import opts as gmr_opts
 
 import nova.conf
 from nova.conf import novnc
+from nova.conf import remote_debug
 from nova.console import websocketproxy
+from nova import objects
 from nova import version
 
 
 CONF = nova.conf.CONF
+remote_debug.register_cli_opts(CONF)
 novnc.register_cli_opts(CONF)
+
 gmr_opts.set_defaults(CONF)
+objects.register_all()
 
 
 def exit_with_error(msg, errno=-1):
@@ -70,6 +75,8 @@ def proxy(host, port, security_proxy=None):
         cert=CONF.cert,
         key=CONF.key,
         ssl_only=CONF.ssl_only,
+        ssl_ciphers=CONF.console.ssl_ciphers,
+        ssl_minimum_version=CONF.console.ssl_minimum_version,
         daemon=CONF.daemon,
         record=CONF.record,
         traffic=not CONF.daemon,
