@@ -11,7 +11,8 @@
 #    under the License.
 
 import datetime
-import mock
+from unittest import mock
+
 from oslo_config import cfg
 from oslo_utils import timeutils
 
