@@ -15,8 +15,6 @@ from nova.tests import fixtures as nova_fixtures
 from nova.tests.functional import fixtures as func_fixtures
 from nova.tests.functional import integrated_helpers
 from nova.tests.unit import fake_network
-import nova.tests.unit.image.fake
-from nova.tests.unit import policy_fixture
 
 
 class TestRescheduleWithVolumesAttached(
@@ -32,10 +30,10 @@ class TestRescheduleWithVolumesAttached(
         super(TestRescheduleWithVolumesAttached, self).setUp()
 
         # Use the new attach flow fixture for cinder
-        cinder_fixture = nova_fixtures.CinderFixture(self)
-        self.cinder = self.useFixture(cinder_fixture)
-        self.useFixture(policy_fixture.RealPolicyFixture())
+        self.cinder = self.useFixture(nova_fixtures.CinderFixture(self))
+        self.useFixture(nova_fixtures.RealPolicyFixture())
         self.useFixture(nova_fixtures.NeutronFixture(self))
+        self.useFixture(nova_fixtures.GlanceFixture(self))
 
         fake_network.set_stub_network_methods(self)
 
@@ -45,9 +43,6 @@ class TestRescheduleWithVolumesAttached(
             api_version='v2.1'))
         self.api = api_fixture.admin_api
 
-        nova.tests.unit.image.fake.stub_out_image_service(self)
-        self.addCleanup(nova.tests.unit.image.fake.FakeImageService_reset)
-
         self.flags(compute_driver='fake.FakeRescheduleDriver')
 
         self.start_service('conductor')
@@ -76,7 +71,7 @@ class TestRescheduleWithVolumesAttached(
         server_response = self.api.post_server({'server': server_request})
         server_id = server_response['id']
 
-        self._wait_for_state_change(self.api, server_response, 'ACTIVE')
+        self._wait_for_state_change(server_response, 'ACTIVE')
         attached_volume_ids = self.cinder.volume_ids_for_instance(server_id)
         self.assertIn(volume_id, attached_volume_ids)
         self.assertEqual(1, len(self.cinder.volume_to_attachment))
