@@ -16,7 +16,8 @@
 Unit Tests for nova.compute.rpcapi
 """
 
-import mock
+from unittest import mock
+
 from oslo_serialization import jsonutils
 from oslo_utils.fixture import uuidsentinel as uuids
 
@@ -40,10 +41,11 @@ class ComputeRpcAPITestCase(test.NoDBTestCase):
         super(ComputeRpcAPITestCase, self).setUp()
         self.context = context.get_admin_context()
         self.fake_flavor_obj = fake_flavor.fake_flavor_obj(self.context)
-        self.fake_flavor = jsonutils.to_primitive(self.fake_flavor_obj)
-        instance_attr = {'host': 'fake_host',
-                         'instance_type_id': self.fake_flavor_obj['id'],
-                         'instance_type': self.fake_flavor_obj}
+        instance_attr = {
+            'host': 'fake_host',
+            'instance_type_id': self.fake_flavor_obj['id'],
+            'flavor': self.fake_flavor_obj,
+        }
         self.fake_instance_obj = fake_instance.fake_instance_obj(self.context,
                                                    **instance_attr)
         self.fake_instance = jsonutils.to_primitive(self.fake_instance_obj)
@@ -833,7 +835,9 @@ class ComputeRpcAPITestCase(test.NoDBTestCase):
             bdms=[], instance=self.fake_instance_obj, host='new_host',
             orig_sys_metadata=None, recreate=True, on_shared_storage=True,
             preserve_ephemeral=True, migration=None, node=None,
-            limits=None, request_spec=None, accel_uuids=[], version='6.0')
+            limits=None, request_spec=None, accel_uuids=[],
+            reimage_boot_volume=False, target_state=None,
+            version='6.2')
 
     def test_rebuild_instance_old_rpcapi(self):
         # With rpcapi < 5.12, accel_uuids must be dropped in the client call.
@@ -860,20 +864,95 @@ class ComputeRpcAPITestCase(test.NoDBTestCase):
             'migration': None,
             'limits': None
         }
+        # Pass reimage_boot_volume to the client call...
         compute_api.rebuild_instance(
             ctxt, instance=self.fake_instance_obj,
             accel_uuids=['938af7f9-f136-4e5a-bdbe-3b6feab54311'],
-            node=None, host=None, **rebuild_args)
+            node=None, host=None, reimage_boot_volume=False,
+            target_state=None, **rebuild_args)
 
-        mock_client.can_send_version.assert_has_calls([mock.call('6.0'),
+        mock_client.can_send_version.assert_has_calls([mock.call('6.2'),
+                                                       mock.call('6.1'),
+                                                       mock.call('6.0'),
                                                        mock.call('5.12')])
         mock_client.prepare.assert_called_with(
                 server=self.fake_instance_obj.host, version='5.0')
+        # ...and assert that it does not show up on the wire before 6.1
         mock_cctx.cast.assert_called_with(  # No accel_uuids
                 ctxt, 'rebuild_instance',
                 instance=self.fake_instance_obj,
                 scheduled_node=None, **rebuild_args)
 
+    def test_rebuild_instance_vol_backed_old_rpcapi(self):
+        # With rpcapi < 6.1, if reimage_boot_volume is True then we
+        # should raise error.
+        ctxt = context.RequestContext('fake_user', 'fake_project')
+        compute_api = compute_rpcapi.ComputeAPI()
+        compute_api.router.client = mock.Mock()
+        mock_client = mock.MagicMock()
+        compute_api.router.client.return_value = mock_client
+        # Force can_send_version to [False, True, True], so that 6.0
+        # version is used.
+        mock_client.can_send_version.side_effect = [False, False, True, True]
+        mock_cctx = mock.MagicMock()
+        mock_client.prepare.return_value = mock_cctx
+        rebuild_args = {
+            'new_pass': 'admin_password',
+            'injected_files': 'files_to_inject',
+            'image_ref': uuids.image_ref,
+            'orig_image_ref': uuids.orig_image_ref,
+            'orig_sys_metadata': 'orig_sys_meta',
+            'bdms': {},
+            'recreate': False,
+            'on_shared_storage': False,
+            'preserve_ephemeral': False,
+            'request_spec': None,
+            'migration': None,
+            'limits': None,
+            'accel_uuids': [],
+            'reimage_boot_volume': True,
+            'target_state': None,
+        }
+        self.assertRaises(
+            exception.NovaException, compute_api.rebuild_instance,
+            ctxt, instance=self.fake_instance_obj,
+            node=None, host=None, **rebuild_args)
+        mock_client.can_send_version.assert_has_calls([mock.call('6.2')])
+
+    def test_rebuild_instance_evacuate_old_rpcapi(self):
+        # With rpcapi < 6.2, if evacuate we should raise error.
+        ctxt = context.RequestContext('fake_user', 'fake_project')
+        compute_api = compute_rpcapi.ComputeAPI()
+        compute_api.router.client = mock.Mock()
+        mock_client = mock.MagicMock()
+        compute_api.router.client.return_value = mock_client
+        # Force can_send_version to return False.
+        mock_client.can_send_version.return_value = False
+        mock_cctx = mock.MagicMock()
+        mock_client.prepare.return_value = mock_cctx
+        rebuild_args = {
+            'new_pass': 'admin_password',
+            'injected_files': 'files_to_inject',
+            'image_ref': uuids.image_ref,
+            'orig_image_ref': uuids.orig_image_ref,
+            'orig_sys_metadata': 'orig_sys_meta',
+            'bdms': {},
+            'recreate': False,
+            'on_shared_storage': False,
+            'preserve_ephemeral': False,
+            'request_spec': None,
+            'migration': None,
+            'limits': None,
+            'accel_uuids': [],
+            'reimage_boot_volume': True,
+            'target_state': 'stopped',
+        }
+        self.assertRaises(
+            exception.UnsupportedRPCVersion,
+            compute_api.rebuild_instance,
+            ctxt, instance=self.fake_instance_obj,
+            node=None, host=None, **rebuild_args)
+
     def test_reserve_block_device_name(self):
         self.flags(long_rpc_timeout=1234)
         self._test_compute_api('reserve_block_device_name', 'call',
@@ -920,7 +999,7 @@ class ComputeRpcAPITestCase(test.NoDBTestCase):
         rpcapi.resize_instance(
             ctxt, instance=self.fake_instance_obj,
             migration=mock.sentinel.migration, image='image',
-            flavor='instance_type', clean_shutdown=True,
+            flavor=self.fake_flavor_obj, clean_shutdown=True,
             request_spec=self.fake_request_spec_obj)
 
         mock_client.can_send_version.assert_has_calls([mock.call('6.0'),
@@ -930,7 +1009,7 @@ class ComputeRpcAPITestCase(test.NoDBTestCase):
         mock_cctx.cast.assert_called_with(
             ctxt, 'resize_instance', instance=self.fake_instance_obj,
             migration=mock.sentinel.migration, image='image',
-            instance_type='instance_type', clean_shutdown=True)
+            instance_type=self.fake_flavor_obj, clean_shutdown=True)
 
     def test_resume_instance(self):
         self._test_compute_api('resume_instance', 'cast',
@@ -1236,7 +1315,7 @@ class ComputeRpcAPITestCase(test.NoDBTestCase):
     def test_version_cap_all_cells_no_access(self, mock_allcells, mock_minver,
                                              mock_log_error):
         """Tests a scenario where nova-compute is configured with a connection
-        to the API database and fails trying to get the minium nova-compute
+        to the API database and fails trying to get the minimum nova-compute
         service version across all cells because nova-compute is configured to
         not allow direct database access.
         """
