@@ -25,11 +25,12 @@ test will then use that DB and username/password combo to run the tests. Refer
 to the 'tools/test-setup.sh' for an example of how to configure this.
 """
 
+from unittest import mock
+
 from alembic import command as alembic_api
 from alembic import script as alembic_script
 import fixtures
 from migrate.versioning import api as migrate_api
-import mock
 from oslo_db.sqlalchemy import enginefacade
 from oslo_db.sqlalchemy import test_fixtures
 from oslo_db.sqlalchemy import test_migrations
@@ -240,6 +241,12 @@ class NovaMigrationsWalk(
             'Index %s on table %s should not exist' % (index, table_name),
         )
 
+    def assertColumnExists(self, connection, table_name, column):
+        self.assertTrue(
+            oslodbutils.column_exists(connection, table_name, column),
+            'Column %s on table %s should exist' % (column, table_name),
+        )
+
     def _migrate_up(self, connection, revision):
         if revision == self.init_version:  # no tests for the initial revision
             alembic_api.upgrade(self.config, revision)
@@ -280,6 +287,42 @@ class NovaMigrationsWalk(
 
         # no check for the MySQL-specific change
 
+    def _check_ccb0fa1a2252(self, connection):
+        for prefix in ('', 'shadow_'):
+            table_name = prefix + 'block_device_mapping'
+            table = oslodbutils.get_table(connection, table_name)
+
+            self.assertColumnExists(connection, table_name, 'encrypted')
+            self.assertColumnExists(
+                connection, table_name, 'encryption_secret_uuid')
+            self.assertColumnExists(
+                connection, table_name, 'encryption_format')
+            self.assertColumnExists(
+                connection, table_name, 'encryption_options')
+
+            # Only check for the expected types if we're using sqlite because
+            # other databases' types may be different. For example, Boolean
+            # may be represented as an integer in MySQL
+            if connection.engine.name != 'sqlite':
+                return
+
+            self.assertIsInstance(table.c.encrypted.type, sa.types.Boolean)
+            self.assertIsInstance(
+                table.c.encryption_secret_uuid.type, sa.types.String)
+            self.assertIsInstance(
+                table.c.encryption_format.type, sa.types.String)
+            self.assertIsInstance(
+                table.c.encryption_options.type, sa.types.String)
+
+    def _check_960aac0e09ea(self, connection):
+        self.assertIndexNotExists(
+            connection, 'console_auth_tokens',
+            'console_auth_tokens_token_hash_idx',
+        )
+        self.assertIndexNotExists(
+            connection, 'instances', 'uuid',
+        )
+
     def test_single_base_revision(self):
         """Ensure we only have a single base revision.
 
