@@ -13,8 +13,8 @@
 #    under the License.
 
 import textwrap
+from unittest import mock
 
-import mock
 import pycodestyle
 
 from nova.hacking import checks
@@ -1020,3 +1020,47 @@ class HackingTestCase(test.NoDBTestCase):
                     nova_utils.ReaderWriterLock()
                """
         self._assert_has_no_errors(code, checks.check_lockutils_rwlocks)
+
+    def test_check_six(self):
+        code = """
+            import six
+            from six import moves
+            from six.moves import range
+            import six.moves.urllib.parse as urlparse
+        """
+        errors = [(x + 1, 0, 'N370') for x in range(4)]
+        self._assert_has_errors(code, checks.check_six, expected_errors=errors)
+
+    def test_import_stock_mock(self):
+        self._assert_has_errors(
+            "import mock",
+            checks.import_stock_mock, expected_errors=[(1, 0, 'N371')])
+        self._assert_has_errors(
+            "from mock import patch",
+            checks.import_stock_mock, expected_errors=[(1, 0, 'N371')])
+        code = """
+                    from unittest import mock
+                    import unittest.mock
+               """
+        self._assert_has_no_errors(code, checks.import_stock_mock)
+
+    def test_check_set_daemon(self):
+        code = """
+                   self.setDaemon(True)
+                   worker.setDaemon(True)
+                   self._event_thread.setDaemon(True)
+                   mythread.setDaemon(False)
+                   self.thread.setDaemon(1)
+               """
+        errors = [(x + 1, 0, 'N372') for x in range(5)]
+        self._assert_has_errors(
+            code, checks.check_set_daemon, expected_errors=errors)
+
+        code = """
+                   self.setDaemon = True
+                   worker.setDaemonFlag(True)
+                   self._event_thread.resetDaemon(True)
+                   self.set.Daemon(True)
+                   self.thread.setdaemon(True)
+               """
+        self._assert_has_no_errors(code, checks.check_set_daemon)
